package com.sample;

import java.io.InputStreamReader;
import java.io.Reader;

import org.drools.RuleBase;
import org.drools.RuleBaseFactory;
import org.drools.WorkingMemory;
import org.drools.compiler.PackageBuilder;
import org.drools.rule.Package;

import data.Person;

public class DroolsTest {

    public static final void main(String[] args) {
        try {
        	
        	//Loading knowledge base
            RuleBase ruleBase = readRules();
            
            //Creating working memory
            WorkingMemory workingMemory = ruleBase.newStatefulSession();
            
            //Creating facts
            Person p = new Person();
            p.setAge(40);
            p.setName("John");
            p.setGender('N');
            
            Person p2 = new Person();
            p2.setAge(26);
            p2.setName("Laura");
            p2.setGender('F');
          
            //Inserting facts into working memory
            workingMemory.insert( p );
            workingMemory.insert( p2 );
            
            //Executing ES
            workingMemory.fireAllRules();   
            
        } catch (Throwable t) {
            t.printStackTrace();
        }
    }

    private static RuleBase readRules() throws Exception {
		//Loading rules from file
		Reader source = new InputStreamReader( DroolsTest.class.getResourceAsStream( "/Sample.drl" ) );
		
		//Creating packages that contain loaded rules
		PackageBuilder builder = new PackageBuilder();
		
		builder.addPackageFromDrl( source );
		
		Package pkg = builder.getPackage();
		
		//Creating an empty knowledge base and then adding rule packages to it
		RuleBase ruleBase = RuleBaseFactory.newRuleBase();
		ruleBase.addPackage( pkg );
		return ruleBase;
	}    
}
