package com.sample;

import java.io.InputStreamReader;
import java.io.Reader;

import org.drools.RuleBase;
import org.drools.RuleBaseFactory;
import org.drools.WorkingMemory;
import org.drools.compiler.PackageBuilder;
import org.drools.rule.Package;

public class DroolsTest {

    public static final void main(String[] args) {
        try {
        	
        	//Loading knowledge base
            RuleBase ruleBase = readRules();
            
            //Creating working memory
            WorkingMemory workingMemory = ruleBase.newStatefulSession();
            
            //Creating facts
            Golfer g1 = new Golfer();
            g1.setName("Fred");
            
            Golfer g2 = new Golfer();
            g2.setName("Bob");
            
            Golfer g3 = new Golfer();
            g3.setName("Tom");
            
            Golfer g4 = new Golfer();
            g4.setName("Joe");
            
            //Printing out initial facts
            System.out.println("Initial facts");
            System.out.println(g1);
            System.out.println(g2);
            System.out.println(g3);
            System.out.println(g4);

            //Inserting facts into working memory
            workingMemory.insert( g1 );
            workingMemory.insert( g2 );
            workingMemory.insert( g3 );
            workingMemory.insert( g4 );
            
            //Executing ES
            workingMemory.fireAllRules();   
            
            //Printing out derived facts
            System.out.println("Derived facts");
            System.out.println(g1);
            System.out.println(g2);
            System.out.println(g3);
            System.out.println(g4);

        } catch (Throwable t) {
            t.printStackTrace();
        }
    }

 	private static RuleBase readRules() throws Exception {
		//Loading rules from file
		Reader source = new InputStreamReader( DroolsTest.class.getResourceAsStream( "/Golf.drl" ) );
		
		//Creating packages that contain loaded rules
		PackageBuilder builder = new PackageBuilder();
		
		builder.addPackageFromDrl( source );
		
		Package pkg = builder.getPackage();
		
		//Creating an empty knowledge base and then adding rule packages to it
		RuleBase ruleBase = RuleBaseFactory.newRuleBase();
		ruleBase.addPackage( pkg );
		return ruleBase;
	}
	
}
